@@ -15,3 +15,6 @@ class AbstractRuntime(AbstractDeploymentBlock):
     @abstractmethod
     def digest(self) -> Infrastructure:
         ...
+
+    def apply_flow_options(self, flow: Flow) -> Flow:
+        return flow
