@@ -3,6 +3,7 @@ from typing import Dict, Optional
 
 from prefect.blocks.core import Block
 from prefect.flows import Flow
+from slugify import slugify
 
 from ..abstract_deployment_block import AbstractDeploymentBlock
 
@@ -28,3 +29,7 @@ class AbstractStorage(AbstractDeploymentBlock):
     @abstractmethod
     def digest(self) -> Optional[Block]:
         ...
+
+    @staticmethod
+    def flow_qualified_name(flow: Flow) -> str:
+        return slugify(flow.name).replace("-", "_")
